@@ -1,3 +1,5 @@
+//! Provides the core configuration functionality.
+
 use crate::config::extended_hashmap::ExtendedMap;
 use crate::config::tree::{parse_conf, ConfigNode};
 use crate::logger::LogLevel;
@@ -20,6 +22,9 @@ pub struct Config {
     pub port: u16,
     /// The number of threads to host the server on
     pub threads: usize,
+    /// The TLS configuration to use
+    #[cfg(feature = "tls")]
+    pub tls_config: Option<TlsConfig>,
     /// Address to forward WebSocket connections to, unless otherwise specified by the route
     pub default_websocket_proxy: Option<String>,
     /// The configuration for different hosts
@@ -37,6 +42,7 @@ pub struct Config {
     pub blacklist: BlacklistConfig,
 }
 
+/// Represents the configuration for a specific host.
 #[derive(Debug, Default, PartialEq)]
 pub struct HostConfig {
     /// Wildcard string specifying what hosts to match, e.g. `*.example.com`
@@ -48,9 +54,13 @@ pub struct HostConfig {
 /// Represents the type of a route.
 #[derive(Debug, PartialEq)]
 pub enum RouteType {
+    /// Serve a single file.
     File,
+    /// Serve a directory of files.
     Directory,
+    /// Proxy requests to this route to another server.
     Proxy,
+    /// Redirect clients to another server.
     Redirect,
 }
 
@@ -98,12 +108,27 @@ pub struct BlacklistConfig {
     pub mode: BlacklistMode,
 }
 
+/// Represents configuration for TLS.
+#[cfg(feature = "tls")]
+#[derive(Clone, Debug, PartialEq, Eq)]
+pub struct TlsConfig {
+    /// The TLS certificate file path.
+    pub cert_file: String,
+    /// The TLS key file path.
+    pub key_file: String,
+    /// Whether to force clients to use HTTPS.
+    pub force: bool,
+}
+
 /// Represents configuration for a plugin.
 #[cfg(feature = "plugins")]
 #[derive(Clone, Debug, PartialEq, Eq)]
 pub struct PluginConfig {
+    /// The name of the plugin.
     pub name: String,
+    /// The path to the shared library file.
     pub library: String,
+    /// The configuration for the plugin.
     pub config: HashMap<String, String>,
 }
 
@@ -181,6 +206,27 @@ impl Config {
             }
         };
 
+        #[cfg(feature = "tls")]
+        let tls_config = {
+            let cert_file = hashmap.get_owned("server.tls.cert_file");
+            let key_file = hashmap.get_owned("server.tls.key_file");
+            let force = hashmap.get_optional("server.tls.force", "false".into());
+
+            if let Some(cert_file) = cert_file {
+                if let Some(key_file) = key_file {
+                    Some(TlsConfig {
+                        cert_file,
+                        key_file,
+                        force: force == "true",
+                    })
+                } else {
+                    return Err("Missing key file for TLS");
+                }
+            } else {
+                None
+            }
+        };
+
         // Get and validate the logging configuration
         let logging = {
             let log_level = hashmap.get_optional_parsed(
@@ -258,6 +304,8 @@ impl Config {
             address,
             port,
             threads,
+            #[cfg(feature = "tls")]
+            tls_config,
             default_websocket_proxy,
             default_host,
             hosts,
