@@ -1,3 +1,5 @@
+//! Provides default values for the configuration.
+
 use crate::config::{
     BlacklistConfig, BlacklistMode, Config, LoggingConfig, RouteConfig, RouteType,
 };
@@ -9,6 +11,8 @@ impl Default for Config {
             address: "0.0.0.0".into(),
             port: 80,
             threads: 32,
+            #[cfg(feature = "tls")]
+            tls_config: None,
             default_websocket_proxy: None,
             hosts: vec![Default::default()],
             default_host: Default::default(),
